@@ -1,5 +1,7 @@
 """QAPyTest is a powerful package for QA specialists built on top of Pytest."""
 
+from faker import Faker
+
 from qapytest._attach import attach
 from qapytest._client_http import GraphQLClient, HttpClient
 from qapytest._json_validation import validate_json
@@ -9,6 +11,7 @@ from qapytest._sql import SqlClient
 from qapytest._step import step
 
 __all__ = [
+    "Faker",
     "GraphQLClient",
     "HttpClient",
     "RedisClient",
